@@ -223,7 +223,8 @@ class IntrinsicResolver:
                     ),
                 )
                 sanitized_dict[sanitized_key] = sanitized_val
-            # On any exception, leave the key:val of the orginal intact and continue on. https://github.com/awslabs/aws-sam-cli/issues/1386
+            # On any exception, leave the key:val of the orginal intact and continue on.
+            # https://github.com/awslabs/aws-sam-cli/issues/1386
             except Exception:
                 if ignore_errors:
                     LOG.debug("Unable to resolve property %s: %s. Leaving as is.", key, val)
@@ -521,7 +522,7 @@ class IntrinsicResolver:
         )
         verify_intrinsic_type_str(intrinsic_value, IntrinsicResolver.FN_GET_AZS)
 
-        if intrinsic_value == "":
+        if not intrinsic_value:
             intrinsic_value = self._symbol_resolver.handle_pseudo_region()
 
         if intrinsic_value not in self._symbol_resolver.REGIONS:
@@ -566,7 +567,8 @@ class IntrinsicResolver:
 
         return location_data
 
-    def handle_fn_import_value(self, intrinsic_value, ignore_errors):
+    @staticmethod
+    def handle_fn_import_value(intrinsic_value, ignore_errors):
         """
         { "Fn::ImportValue" : sharedValueToImport }
         This intrinsic function requires handling multiple stacks, which is not currently supported by SAM-CLI.
